==> pholiday-0.1.6.tgz: package/events/lunar.js <==
module.exports = [
    {'fday':'7/1', 'title': 'ولادت امام محمد باقر علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/3', 'title': 'شهادت امام علی النقی الهادی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/10', 'title': 'ولادت امام محمد تقی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/13', 'title': 'ولادت امام علی علیه السلام و روز پدر', 'holiday': true, isLunar: true},
    {'fday':'7/15', 'title': 'وفات حضرت زینب سلام الله علیها', 'holiday': false, isLunar: true},
    {'fday':'7/25', 'title': 'شهادت امام موسی کاظم علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/27', 'title': 'مبعث رسول اکرم', 'holiday': true, isLunar: true},
    {'fday':'8/3', 'title': 'ولادت سالار شهیدان، امام حسین علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'8/4', 'title': 'ولادت ابوالفضل العباس علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'8/5', 'title': 'ولادت امام زین العابدین علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'8/11', 'title': 'ولادت علی اکبر علیه السلام و روز جوان', 'holiday': false, isLunar: true},
    {'fday':'8/15', 'title': 'ولادت حضرت قائم عجل الله تعالی فرجه و جشن نیمه شعبان', 'holiday': false, isLunar: true},
    {'fday':'9/15', 'title': 'ولادت امام حسن مجتبی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'9/18', 'title': 'شب قدر', 'holiday': false, isLunar: true},
    {'fday':'9/19', 'title': 'ضربت خوردن حضرت علی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'9/21', 'title': 'شهادت حضرت علی علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'9/22', 'title': 'شب قدر', 'holiday': true, isLunar: true},
    {'fday':'10/1', 'title': 'عید سعید فطر', 'holiday': true, isLunar: true},
    {'fday':'10/2', 'title': 'تعطیل به مناسبت عید سعید فطر', 'holiday': true, isLunar: true},
    {'fday':'10/25', 'title': 'شهادت امام جعفر صادق علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'11/1', 'title': 'ولادت حضرت معصومه سلام الله علیها و روز دختران', 'holiday': false, isLunar: true},
    {'fday':'11/11', 'title': 'ولادت امام رضا علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'11/29', 'title': 'شهادت امام محمد تقی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/7', 'title': 'شهادت امام محمد باقرعلیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/9', 'title': 'روز عرفه', 'holiday': false, isLunar: true},
    {'fday':'12/10', 'title': 'عید سعید قربان', 'holiday': true, isLunar: true},
    {'fday':'12/15', 'title': 'ولادت امام علی النقی الهادی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/18', 'title': 'عید سعید غدیر خم', 'holiday': true, isLunar: true},
    {'fday':'12/20', 'title': 'ولادت امام موسی کاظم علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/20', 'title': 'ولادت امام موسی کاظم علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'1/9', 'title': 'تاسوعای حسینی', 'holiday': true, isLunar: true},
    {'fday':'1/10', 'title': 'عاشورای حسینی', 'holiday': true, isLunar: true},
    {'fday':'1/12', 'title': 'شهادت امام زین العابدین علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'1/12', 'title': 'شهادت امام زین العابدین علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'2/20', 'title': 'اربعین حسینی', 'holiday': true, isLunar: true},
    {'fday':'2/28', 'title': 'رحلت رسول اکرم؛شهادت امام حسن مجتبی علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'2/28', 'title': 'رحلت رسول اکرم؛شهادت امام حسن مجتبی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'2/30', 'title': 'شهادت امام رضا علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'3/1', 'title': 'هجرت پیامبر اکرم از مکه به مدینه', 'holiday': false, isLunar: true},
    {'fday':'3/8', 'title': 'شهادت امام حسن عسکری علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'3/12', 'title': 'میلاد رسول اکرم به روایت اهل سنت', 'holiday': false, isLunar: true},
    {'fday':'3/17', 'title': 'میلاد رسول اکرم و امام جعفر صادق علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'4/10', 'title': 'وفات حضرت معصومه سلام الله علیها', 'holiday': false, isLunar: true},
    {'fday':'5/5', 'title': 'ولادت حضرت زینب سلام الله علیها و روز پرستار و بهورز', 'holiday': false, isLunar: true},
    {'fday':'6/3', 'title': 'شهادت حضرت فاطمه زهرا سلام الله علیها', 'holiday': true, isLunar: true},
    {'fday':'6/20', 'title': 'ولادت حضرت فاطمه زهرا سلام الله علیها و روز زن', 'holiday': false, isLunar: true},
    {'fday':'6/29', 'title': 'ولادت امام محمد باقر علیه السلام', 'holiday': false, isLunar: true},


    // {'day': 75, 'title': 'ولادت حضرت فاطمه و روز زن', 'holiday': false, isLunar: true},
    // {'day': 98, 'title': 'ولادت امام علی', 'holiday': true, isLunar: true},
    // {'day': 112, 'title': 'مبعث حضرت رسول اکرم', 'holiday': true, isLunar: true},
    // {'day': 129, 'title': 'ولادت حضرت قائم', 'holiday': true, isLunar: true},
    // {'day': 164, 'title': 'شهادت حضرت علی', 'holiday': true, isLunar: true},
    // {'day': 174, 'title': 'عید فطر', 'holiday': true, isLunar: true},
    // {'day': 198, 'title': 'شهادت اما جعفر صادق', 'holiday': true, isLunar: true},
    // {'day': 242, 'title': 'عید قربان', 'holiday': true, isLunar: true},
    // {'day': 250, 'title': 'عید غدیر خم', 'holiday': true, isLunar: true},
    // {'day': 270, 'title': 'تاسوعای حسینی', 'holiday': true, isLunar: true},
    // {'day': 271, 'title': 'عاشورای حسینی', 'holiday': true, isLunar: true},
    // {'day': 311, 'title': 'اربعین حسینی', 'holiday': true, isLunar: true},
    // {'day': 319, 'title': 'رحلت حضرت رسول اکرم و شهادت امام حسن مجتبی', 'holiday': true, isLunar: true},
    // {'day': 321, 'title': 'شهادت امام رضا', 'holiday': true, isLunar: true},
    // {'day': 338, 'title': 'میلاد حضرت رسول اکرم و اما جعفر صادق', 'holiday': true, isLunar: true},
]

==> pholiday-0.2.1.tgz: package/events/lunar.js <==
module.exports = [
    {'fday':'7/1', 'title': 'ولادت امام محمد باقر علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/3', 'title': 'شهادت امام علی النقی الهادی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/10', 'title': 'ولادت امام محمد تقی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/13', 'title': 'ولادت امام علی علیه السلام و روز پدر', 'holiday': true, isLunar: true},
    {'fday':'7/15', 'title': 'وفات حضرت زینب سلام الله علیها', 'holiday': false, isLunar: true},
    {'fday':'7/25', 'title': 'شهادت امام موسی کاظم علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'7/27', 'title': 'مبعث رسول اکرم', 'holiday': true, isLunar: true},
    {'fday':'8/3', 'title': 'ولادت سالار شهیدان، امام حسین علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'8/4', 'title': 'ولادت ابوالفضل العباس علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'8/5', 'title': 'ولادت امام زین العابدین علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'8/11', 'title': 'ولادت علی اکبر علیه السلام و روز جوان', 'holiday': false, isLunar: true},
    {'fday':'8/15', 'title': 'ولادت حضرت قائم عجل الله تعالی فرجه و جشن نیمه شعبان', 'holiday': false, isLunar: true},
    {'fday':'9/15', 'title': 'ولادت امام حسن مجتبی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'9/18', 'title': 'شب قدر', 'holiday': false, isLunar: true},
    {'fday':'9/19', 'title': 'ضربت خوردن حضرت علی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'9/21', 'title': 'شهادت حضرت علی علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'9/22', 'title': 'شب قدر', 'holiday': true, isLunar: true},
    {'fday':'10/2', 'title': 'عید سعید فطر', 'holiday': true, isLunar: true},//bugs
    {'fday':'10/3', 'title': 'تعطیل به مناسبت عید سعید فطر', 'holiday': true, isLunar: true},//bugs
    {'fday':'10/26', 'title': 'شهادت امام جعفر صادق علیه السلام', 'holiday': true, isLunar: true},//bugs
    {'fday':'11/2', 'title': 'ولادت حضرت معصومه سلام الله علیها و روز دختران', 'holiday': false, isLunar: true},//bugs
    {'fday':'11/12', 'title': 'ولادت امام رضا علیه السلام', 'holiday': false, isLunar: true},//bugs
    {'fday':'11/30', 'title': 'شهادت امام محمد تقی علیه السلام', 'holiday': false, isLunar: true},//bugs
    {'fday':'12/7', 'title': 'شهادت امام محمد باقرعلیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/9', 'title': 'روز عرفه', 'holiday': false, isLunar: true},
    {'fday':'12/10', 'title': 'عید سعید قربان', 'holiday': true, isLunar: true},
    {'fday':'12/15', 'title': 'ولادت امام علی النقی الهادی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/18', 'title': 'عید سعید غدیر خم', 'holiday': true, isLunar: true},
    {'fday':'12/20', 'title': 'ولادت امام موسی کاظم علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'12/20', 'title': 'ولادت امام موسی کاظم علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'1/10', 'title': 'تاسوعای حسینی', 'holiday': true, isLunar: true},//bugs
    {'fday':'1/11', 'title': 'عاشورای حسینی', 'holiday': true, isLunar: true},//bugs
    {'fday':'1/13', 'title': 'شهادت امام زین العابدین علیه السلام', 'holiday': false, isLunar: true},//bugs
    {'fday':'1/14', 'title': 'شهادت امام زین العابدین علیه السلام', 'holiday': false, isLunar: true},//bugs
    {'fday':'2/20', 'title': 'اربعین حسینی', 'holiday': true, isLunar: true},
    {'fday':'2/28', 'title': 'رحلت رسول اکرم؛شهادت امام حسن مجتبی علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'2/28', 'title': 'رحلت رسول اکرم؛شهادت امام حسن مجتبی علیه السلام', 'holiday': false, isLunar: true},
    {'fday':'2/30', 'title': 'شهادت امام رضا علیه السلام', 'holiday': true, isLunar: true},
    {'fday':'3/1', 'title': 'هجرت پیامبر اکرم از مکه به مدینه', 'holiday': false, isLunar: true},
    {'fday':'3/9', 'title': 'شهادت امام حسن عسکری علیه السلام', 'holiday': true, isLunar: true},//bugs
    {'fday':'3/13', 'title': 'میلاد رسول اکرم به روایت اهل سنت', 'holiday': false, isLunar: true},//bugs
    {'fday':'3/18', 'title': 'میلاد رسول اکرم و امام جعفر صادق علیه السلام', 'holiday': true, isLunar: true},//bugs
    {'fday':'4/11', 'title': 'وفات حضرت معصومه سلام الله علیها', 'holiday': false, isLunar: true},//bugs
    {'fday':'5/6', 'title': 'ولادت حضرت زینب سلام الله علیها و روز پرستار و بهورز', 'holiday': false, isLunar: true},//bugs
    {'fday':'6/4', 'title': 'شهادت حضرت فاطمه زهرا سلام الله علیها', 'holiday': true, isLunar: true},//bugs
    {'fday':'6/21', 'title': 'ولادت حضرت فاطمه زهرا سلام الله علیها و روز زن', 'holiday': false, isLunar: true},//bugs
    {'fday':'6/30', 'title': 'ولادت امام محمد باقر علیه السلام', 'holiday': false, isLunar: true},


    // {'day': 75, 'title': 'ولادت حضرت فاطمه و روز زن', 'holiday': false, isLunar: true},
    // {'day': 98, 'title': 'ولادت امام علی', 'holiday': true, isLunar: true},
    // {'day': 112, 'title': 'مبعث حضرت رسول اکرم', 'holiday': true, isLunar: true},
    // {'day': 129, 'title': 'ولادت حضرت قائم', 'holiday': true, isLunar: true},
    // {'day': 164, 'title': 'شهادت حضرت علی', 'holiday': true, isLunar: true},
    // {'day': 174, 'title': 'عید فطر', 'holiday': true, isLunar: true},
    // {'day': 198, 'title': 'شهادت اما جعفر صادق', 'holiday': true, isLunar: true},
    // {'day': 242, 'title': 'عید قربان', 'holiday': true, isLunar: true},
    // {'day': 250, 'title': 'عید غدیر خم', 'holiday': true, isLunar: true},
    // {'day': 270, 'title': 'تاسوعای حسینی', 'holiday': true, isLunar: true},
    // {'day': 271, 'title': 'عاشورای حسینی', 'holiday': true, isLunar: true},
    // {'day': 311, 'title': 'اربعین حسینی', 'holiday': true, isLunar: true},
    // {'day': 319, 'title': 'رحلت حضرت رسول اکرم و شهادت امام حسن مجتبی', 'holiday': true, isLunar: true},
    // {'day': 321, 'title': 'شهادت امام رضا', 'holiday': true, isLunar: true},
    // {'day': 338, 'title': 'میلاد حضرت رسول اکرم و اما جعفر صادق', 'holiday': true, isLunar: true},
]
